<?php
/**
 * @version		$Id: mega.tpl.functions.php 1.0 Dec 28, 2010 19:02:38Z OmegaTheme $
 * @package		OmegaTheme Joomla Template
 * @subpackage	MegaRealist
 * @author		OmegaTheme (services@omegatheme.com)
 * @link 		http://www.omegatheme.com
 * @copyright	Copyright (C) 2008 - 2010 OmegaTheme
 * @license		GNU/GPL V2
 * @description	This file contains template-classes with template-functions. For common using.
*/

class megaTemplate
{

	/* document */
	var $document;

	/* template url */
	var $url;

	/* parameters */
	var $params;

	/* browser */
	var $browser = array();
	
	/**
	 * function megaTemplate();
	 *
	 * @description		Load params of template, get browser type
	 * @call			megaTemplate() <- loadFile()+ loadPageSuffix()
	 * @return 			void
	 */
	function megaTemplate()
	{
		$this->params = new megaTemplateParameter();
		//load params file
		$this->params->loadFile(dirname(dirname(__FILE__)).'/params.ini');
		//to avoid cross
		$this->params->getPageSuffix();
		// what ie browser version?
		if (array_key_exists('HTTP_USER_AGENT', $_SERVER) && preg_match('/(MSIE\\s?([\\d\\.]+))/', $_SERVER['HTTP_USER_AGENT'], $matches))
		{
			$this->browser['ie8'] = intval($matches[2]) == 8;
			$this->browser['ie7'] = intval($matches[2]) == 7;
			$this->browser['ie6'] = intval($matches[2]) == 6;
		}		
	}
	
	/**
	 * function  &getInstance();
	 * @return		Template object
	 */
	function &getInstance()
	{
		static $instance;

		if ($instance == null) {
			$instance = new megaTemplate();
		}
		return $instance;
	}

	function setDocument(&$document)
	{
		$this->document =& $document;
		$this->url = $document->baseurl.'/templates/'.$document->template;
	}

	/**
	 * function isIe($version);
	 *
	 * @description		Check for IE browser version
	 * @call
	 * @return			false if not IE, else return version of IE
	 */
	function isIe($version)
	{
		if (array_key_exists('ie'.$version, $this->browser)) {
			return $this->browser['ie'.$version];
		}
		return false;
	}
	
	/**
	 * function isHome();
	 *
	 * @description		Check for home menuitem
	 * @call
	 * @return			Boolean
	 */
	function isHome()
	{
		$mnu =& JSite::getMenu();
		return ($mnu->getActive() == $mnu->getDefault());
	}
	
	/**
	 * function isFrontpage();
	 *
	 * @description		Check for Frontpage menuitem
	 * @call
	 * @return			Boolean
	 */
	function isFrontpage() {
		return (JRequest::getCmd( 'view' ) == 'frontpage') ;
	}
	
	/**
	 * function getCSS();
	 *
	 * @description		Custom Styling - setting wrapper and column size from params 
	 * @call
	 * @return			StyleSheet string
	 */
	function getCSS()
	{
		$unit = $this->params->get('template_width_unit');

		$css = '.header-inner, .menu-bar-inner, .middle-outer { width: '.intval($this->params->get('template_width')).$unit."; }\n";
		/* left */
		if ($this->document->countModules('left'))
		{
			$css .= '#left { width: '.intval($this->params->get('left_width')).$unit.'; margin-left: '.intval($this->params->get('left_space')).$unit."; }\n";
		}
		/* right */
		if ($this->document->countModules('right'))
		{
			$css .= '#right { width: '.intval($this->params->get('right_width')).$unit.'; margin-left: '.intval($this->params->get('right_space')).$unit."; }\n";
		}	
		return $css;
	}

}
/* end of class megaTemplate */

class megaTemplateParameter
{

	/* parameters */
	var $params = array();

	function megaTemplateParameter($data = null) {
		$this->parseString($data);
	}
	
	/**
	 * function get($key, $default = '');
	 *
	 * @description		Get template params
	 * @call
	 * @return			array or empty string
	 */
	function get($key, $default = '')
	{
		if (array_key_exists($key, $this->params))
		{
			return $this->params[$key];
		}
		return $default;
	}
	
	/**
	 * function set($key, $value);
	 *
	 * @description		Set template params
	 * @call
	 * @return			void
	 */
	function set($key, $value) {
		$this->params[$key] = $value;
	}

	function toArray() {
		return $this->params;
	}
	
	/**
	 * function loadFile($file);
	 *
	 * @description		Load file for readonly (params file)
	 * @call
	 * @return			void
	 */
	function loadFile($file)
	{
		if (is_file($file))
		{
			$handle = fopen($file, 'r');
			if ($handle !== false)
			{
				while ($l = fgets($handle))
				{
					if (preg_match('/^#/', $l) == false)
					{
						if (preg_match('/^(.*?)=(.*?)$/', $l, $regs)) {
							$this->params[$regs[1]] = $regs[2];
						}
					}
				}
				@fclose($handle);
			}
		}
	}

	function parseString($string)
	{
		$parts = preg_split('/[\s]+/', $string);

		foreach ($parts as $part)
		{
			if (strpos($part, '-') !== false)
			{
				list($key, $value) = split('-', $part, 2);
				$this->params[$key] = $value;
			}
		}
	}
	
	function getPageSuffix()
	{
		global $mainframe;

		// read parameters from joomla page class suffix
		if (isset($mainframe))
		{
			$params =& $mainframe->getParams();
			$this->parseString($params->get('pageclass_sfx'));
		}
	}
}
/* end of class megaTemplateParameter */